@@ -1,21 +1,7 @@
 /*
-    Copyright 2012-2013  Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2012-2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef NETWORKMANAGERQT_INFINIBAND_SETTING_H
@@ -24,7 +10,7 @@
 #include <networkmanagerqt/networkmanagerqt_export.h>
 #include "setting.h"
 
-#include <QtCore/QString>
+#include <QString>
 
 namespace NetworkManager
 {
@@ -43,9 +29,9 @@ public:
 
     InfinibandSetting();
     explicit InfinibandSetting(const Ptr &other);
-    ~InfinibandSetting();
+    ~InfinibandSetting() override;
 
-    QString name() const Q_DECL_OVERRIDE;
+    QString name() const override;
 
     void setMacAddress(const QByteArray &address);
     QByteArray macAddress() const;
@@ -56,17 +42,15 @@ public:
     void setTransportMode(TransportMode mode);
     TransportMode transportMode() const;
 
-#if NM_CHECK_VERSION(0, 9, 10)
     void setPKey(qint32 key);
     qint32 pKey() const;
 
     void setParent(const QString &parent);
     QString parent() const;
 
-#endif
-    void fromMap(const QVariantMap &setting) Q_DECL_OVERRIDE;
+    void fromMap(const QVariantMap &setting) override;
 
-    QVariantMap toMap() const Q_DECL_OVERRIDE;
+    QVariantMap toMap() const override;
 
 protected:
     InfinibandSettingPrivate *d_ptr;
